==> nextcloud-30.0.5.tgz: nextcloud/apps/systemtags/l10n/zh_TW.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "系統已新增系統標籤 %1$s",
    "Added system tag {systemtag}" : "已新增系統標籤 {systemtag}",
    "Added system tag %1$s" : "已新增系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已新增系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已新增系統標籤 {systemtag}",
    "System tag %1$s removed by the system" : "系統已移除系統標籤 %1$s",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您建立了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您建立了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 建立了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 建立了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您將系統標籤 %2$s 更新為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您將系統標籤 {oldsystemtag} 更新為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 將系統標籤 %3$s 更新為 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 將系統標籤 {oldsystemtag} 更新為 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系統標籤 %2$s 已被系統新增至 %1$s",
    "System tag {systemtag} was added to {file} by the system" : "系統標籤 {systemtag} 已被系統新增至 {file}",
    "You added system tag %2$s to %1$s" : "您已新增系統標籤 %2$s 至 %1$s",
    "You added system tag {systemtag} to {file}" : "您已新增系統標籤 {systemtag} 至 {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 已新增系統標籤 %3$s 至 %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 已新增系統標籤 {systemtag} 至 {file}",
    "System tag %2$s was removed from %1$s by the system" : "系統標籤 %2$s 已被系統從 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系統標籤 {systemtag} 已被系統從 {file} 移除",
    "You removed system tag %2$s from %1$s" : "您已從 %1$s 移除系統標籤 %2$s",
    "You removed system tag {systemtag} from {file}" : "您已從 {file} 移除系統標籤 {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 已從 %2$s 移除系統標籤 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 已從 {file} 移除系統標籤 {systemtag}",
    "%s (restricted)" : "%s（受限）",
    "%s (invisible)" : "%s（隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "檔案的<strong>系統標籤</strong>已被修改",
    "Files" : "檔案",
    "Tags" : "標籤",
    "All tagged %s …" : "全部標籤為 %s…",
    "tagged %s" : "標籤為 %s",
    "Collaborative tags" : "協作標籤",
    "Collaborative tagging functionality which shares tags among people." : "可在使用者間分享標籤的協作標籤功能。",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "可在使用者間分享標籤的協作標籤功能。對團隊來說很有用。\n\t（如果您是有多租戶安裝的提供商，則建議在分享標籤時停用此應用程式。）",
    "Create or edit tags" : "建立或編輯標籤",
    "Search for a tag to edit" : "搜尋要編輯的標籤",
    "Collaborative tags …" : "協作標籤…",
    "No tags to select" : "未選取標籤",
    "Tag name" : "標籤名稱",
    "Tag level" : "標籤層級",
    "Create" : "建立",
    "Update" : "更新",
    "Delete" : "刪除",
    "Reset" : "重設",
    "Loading …" : "正在載入…",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Created tag" : "已建立標籤",
    "Failed to create tag" : "標籤建立失敗",
    "Updated tag" : "已更新標籤",
    "Failed to update tag" : "標籤更新失敗",
    "Deleted tag" : "已刪除標籤",
    "Failed to delete tag" : "標籤刪除失敗",
    "Manage tags" : "管理標籤",
    "Applying tags changes…" : "正在套用標籤變更……",
    "Search or create tag" : "搜尋或建立標籤",
    "Change tag color" : "變更標籤顏色",
    "Create new tag" : "建立新標籤",
    "Select or create tags to apply to all selected files" : "選取或建立標籤以套用至所有選定的檔案",
    "Cancel" : "取消",
    "Apply changes" : "套用變更",
    "{displayName} (hidden)" : "{displayName}（隱藏）",
    "{displayName} (restricted)" : "{displayName}（受限）",
    "Failed to apply tags changes" : "套用標籤變更失敗",
    "File tags modification canceled" : "已取消檔案標籤修改",
    "Loading collaborative tags …" : "正在載入協作標籤…",
    "Search or create collaborative tags" : "搜尋或建立協作標籤",
    "No tags to select, type to create a new tag" : "無可供選取的標籤，輸入以建立新標籤",
    "Failed to load tags" : "標籤載入失敗",
    "Failed to load selected tags" : "選定的標籤載入失敗",
    "Failed to select tag" : "標籤選取失敗",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "協作標籤適用於所有使用者。使用者可以看到受限的標籤，但無法由他們指派。不可見的隱藏標籤僅供內部使用，因為使用者無法看見或指派它們。",
    "Assigned collaborative tags" : "已分配的協作標籤",
    "Open in Files" : "在「檔案」應用程式中開啟",
    "List of tags and their associated files and folders." : "標籤及其關聯檔案與資料夾的清單。",
    "No tags found" : "找不到標籤",
    "Tags you have created will show up here." : "您建立的標籤將會顯示在此處。",
    "Failed to load tag" : "載入標籤失敗",
    "Failed to load last used tags" : "上次使用的標籤載入失敗",
    "Missing \"Content-Location\" header" : "缺少「Content-Location」標頭",
    "A tag with the same name already exists" : "已有相同名稱的標籤",
    "Failed to load tags for file" : "檔案的標籤載入失敗",
    "Failed to set tag for file" : "檔案的標籤設定失敗",
    "Failed to delete tag for file" : "檔案的標籤刪除失敗",
    "Collaborative tagging functionality which shares tags among users." : "可在使用者間分享標籤的協作標籤功能。",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "可在使用者間分享標籤的協作標籤功能。對團隊來說很有用。\n\t（如果您是有多租戶安裝的提供商，基於標籤會分享的緣故，建議停用此應用程式。）",
    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
    "No files in here" : "沒有任何檔案",
    "No entries found in this folder" : "此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.11.tgz: nextcloud/apps/systemtags/l10n/zh_TW.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "系統已新增系統標籤 %1$s",
    "Added system tag {systemtag}" : "已新增系統標籤 {systemtag}",
    "Added system tag %1$s" : "已新增系統標籤 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已新增系統標籤 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已新增系統標籤 {systemtag}",
    "System tag %1$s removed by the system" : "系統已移除系統標籤 %1$s",
    "Removed system tag {systemtag}" : "已移除系統標籤 {systemtag}",
    "Removed system tag %1$s" : "已移除系統標籤 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 已移除系統標籤 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 已移除系統標籤 {systemtag}",
    "You created system tag %1$s" : "您建立了系統標籤 %1$s",
    "You created system tag {systemtag}" : "您建立了系統標籤 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 建立了系統標籤 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 建立了系統標籤 {systemtag}",
    "You deleted system tag %1$s" : "您刪除了系統標籤 %1$s",
    "You deleted system tag {systemtag}" : "您刪除了系統標籤 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 刪除了系統標籤 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 刪除了系統標籤 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您將系統標籤 %2$s 更新為 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您將系統標籤 {oldsystemtag} 更新為 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 將系統標籤 %3$s 更新為 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 將系統標籤 {oldsystemtag} 更新為 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系統標籤 %2$s 已被系統新增至 %1$s",
    "System tag {systemtag} was added to {file} by the system" : "系統標籤 {systemtag} 已被系統新增至 {file}",
    "You added system tag %2$s to %1$s" : "您已新增系統標籤 %2$s 至 %1$s",
    "You added system tag {systemtag} to {file}" : "您已新增系統標籤 {systemtag} 至 {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 已新增系統標籤 %3$s 至 %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 已新增系統標籤 {systemtag} 至 {file}",
    "System tag %2$s was removed from %1$s by the system" : "系統標籤 %2$s 已被系統從 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系統標籤 {systemtag} 已被系統從 {file} 移除",
    "You removed system tag %2$s from %1$s" : "您已從 %1$s 移除系統標籤 %2$s",
    "You removed system tag {systemtag} from {file}" : "您已從 {file} 移除系統標籤 {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 已從 %2$s 移除系統標籤 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 已從 {file} 移除系統標籤 {systemtag}",
    "%s (restricted)" : "%s（受限）",
    "%s (invisible)" : "%s（隱藏）",
    "<strong>System tags</strong> for a file have been modified" : "檔案的<strong>系統標籤</strong>已被修改",
    "Files" : "檔案",
    "Tags" : "標籤",
    "All tagged %s …" : "全部標籤為 %s…",
    "tagged %s" : "標籤為 %s",
    "Collaborative tags" : "協作標籤",
    "Collaborative tagging functionality which shares tags among people." : "可在使用者間分享標籤的協作標籤功能。",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "可在使用者間分享標籤的協作標籤功能。對團隊來說很有用。\n\t（如果您是有多租戶安裝的提供商，則建議在分享標籤時停用此應用程式。）",
    "Public" : "公開",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Created tag" : "已建立標籤",
    "Failed to create tag" : "標籤建立失敗",
    "Updated tag" : "已更新標籤",
    "Failed to update tag" : "標籤更新失敗",
    "Deleted tag" : "已刪除標籤",
    "Failed to delete tag" : "標籤刪除失敗",
    "Create or edit tags" : "建立或編輯標籤",
    "Search for a tag to edit" : "搜尋要編輯的標籤",
    "Collaborative tags …" : "協作標籤…",
    "No tags to select" : "未選取標籤",
    "Tag name" : "標籤名稱",
    "Tag level" : "標籤層級",
    "Create" : "建立",
    "Update" : "更新",
    "Delete" : "刪除",
    "Reset" : "重設",
    "Loading …" : "正在載入…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["將會設定 {tag1}，並從 {count} 個檔案中移除 {tag2}。"],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["將會設定 {tag} 到 {count} 個檔案。"],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["將會從 {count} 個檔案移除 {tag}。"],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["將會設定 {tags} 與 {lastTag} 到 {count} 個檔案。"],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["將從 {count} 個檔案移除 {tags} 與 {lastTag}"],
    "{displayName} (hidden)" : "{displayName}（隱藏）",
    "{displayName} (restricted)" : "{displayName}（受限）",
    "Only admins can create new tags" : "僅有管理員可以建立新標籤",
    "Failed to apply tags changes" : "套用標籤變更失敗",
    "File tags modification canceled" : "已取消檔案標籤修改",
    "Manage tags" : "管理標籤",
    "Applying tags changes…" : "正在套用標籤變更……",
    "Search or create tag" : "搜尋或建立標籤",
    "Search tag" : "搜尋標籤",
    "Change tag color" : "變更標籤顏色",
    "Create new tag" : "建立新標籤",
    "Select or create tags to apply to all selected files" : "選取或建立標籤以套用至所有選定的檔案",
    "Select tags to apply to all selected files" : "選取要套用到所有選取檔案的標籤",
    "Cancel" : "取消",
    "Apply changes" : "套用變更",
    "Failed to load tags" : "標籤載入失敗",
    "Failed to load selected tags" : "選定的標籤載入失敗",
    "Failed to select tag" : "標籤選取失敗",
    "System admin disabled tag creation. You can only use existing ones." : "系統管理員已停用標籤建立功能。您僅能使用現有的。",
    "Loading collaborative tags …" : "正在載入協作標籤…",
    "Search or create collaborative tags" : "搜尋或建立協作標籤",
    "No tags to select, type to create a new tag" : "無可供選取的標籤，輸入以建立新標籤",
    "Unable to update setting" : "無法更新設定",
    "System tag creation is now restricted to administrators" : "系統標籤現在僅限管理員建立",
    "System tag creation is now allowed for everybody" : "現在所有人都可以建立系統標籤",
    "System tag management" : "系統標籤管理",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "若啟用，僅有管理員可以建立與編輯標籤。一般帳號仍可分配與移除檔案中的標籤。",
    "Restrict tag creation and editing to administrators" : "限制僅管理員才能建立與編輯標籤",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "協作標籤適用於所有使用者。使用者可以看到受限的標籤，但無法由他們指派。不可見的隱藏標籤僅供內部使用，因為使用者無法看見或指派它們。",
    "Assigned collaborative tags" : "已分配的協作標籤",
    "Open in Files" : "在「檔案」應用程式中開啟",
    "List of tags and their associated files and folders." : "標籤及其關聯檔案與資料夾的清單。",
    "No tags found" : "找不到標籤",
    "Tags you have created will show up here." : "您建立的標籤將會顯示在此處。",
    "Failed to load tag" : "載入標籤失敗",
    "Failed to load last used tags" : "上次使用的標籤載入失敗",
    "Missing \"Content-Location\" header" : "缺少「Content-Location」標頭",
    "A tag with the same name already exists" : "已有相同名稱的標籤",
    "Failed to load tags for file" : "檔案的標籤載入失敗",
    "Failed to set tag for file" : "檔案的標籤設定失敗",
    "Failed to delete tag for file" : "檔案的標籤刪除失敗",
    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}"
},
"nplurals=1; plural=0;");
